@@ -108,6 +108,10 @@ def parse_response(
             or output.type == "image_generation_call"
             or output.type == "code_interpreter_call"
             or output.type == "local_shell_call"
+            or output.type == "shell_call"
+            or output.type == "shell_call_output"
+            or output.type == "apply_patch_call"
+            or output.type == "apply_patch_call_output"
             or output.type == "mcp_list_tools"
             or output.type == "exec"
             or output.type == "custom_tool_call"
